Hooks:PostHook( MenuSceneManager, "_get_lobby_character_prio_item", "HenchShowWeapons", function(self, rank, outfit)
	local infamous = rank and rank > 0
	local primary_rarity, secondary_rarity
	if outfit.primary.cosmetics and outfit.primary.cosmetics.id and outfit.primary.cosmetics.id ~= "nil" then
		local rarity = tweak_data.blackmarket.weapon_skins[outfit.primary.cosmetics.id] and tweak_data.blackmarket.weapon_skins[outfit.primary.cosmetics.id].rarity
		primary_rarity = tweak_data.economy.rarities[rarity].index
	end
	if outfit.secondary.cosmetics and outfit.secondary.cosmetics.id and outfit.secondary.cosmetics.id ~= "nil" then
		local rarity = tweak_data.blackmarket.weapon_skins[outfit.secondary.cosmetics.id] and tweak_data.blackmarket.weapon_skins[outfit.secondary.cosmetics.id].rarity
		secondary_rarity = tweak_data.economy.rarities[rarity].index
	end
	if primary_rarity and secondary_rarity then
		return primary_rarity >= secondary_rarity and "primary" or "secondary"
	elseif primary_rarity then
		return "primary"
	elseif secondary_rarity then
		return "secondary"
	end
	if not primary_rarity and not secondary_rarity then
		return "primary" -- Feel free to change this to showoff either primaries or secondaries without skins. "primary" or "secondary"
	end
	return infamous and "rank" or "primary"
end)

function MenuSceneManager:_select_lobby_character_pose(peer_id, unit, weapon_info)
	local state = unit:play_redirect(Idstring("idle_menu"))
	local weapon_id = managers.weapon_factory:get_weapon_id_by_factory_id(weapon_info.factory_id)
	local category = tweak_data.weapon[weapon_id].categories[1]
	local lobby_poses = self._lobby_poses[weapon_id]
	lobby_poses = lobby_poses or self._lobby_poses[category]
	lobby_poses = lobby_poses or self._lobby_poses.generic

	if type(lobby_poses[1]) == "string" then
		local pose = lobby_poses[math.random(#lobby_poses)]
		unit:anim_state_machine():set_parameter(state, pose, 1)
	else
		local pose = lobby_poses[peer_id][math.random(#lobby_poses[peer_id])]
		unit:anim_state_machine():set_parameter(state, pose, 1)
	end
end

function MenuSceneManager:set_lobby_character_out_fit(i, outfit_string, rank)
	local outfit = managers.blackmarket:unpack_outfit_from_string(outfit_string)
	local character = outfit.character

	if managers.network:session() then
		if not managers.network:session():peer(i) then
			return
		end

		character = managers.network:session():peer(i):character_id()
	end

	self:change_lobby_character(i, character)

	local unit = self._lobby_characters[i]
	local mask_blueprint = managers.blackmarket:mask_blueprint_from_outfit_string(outfit_string)

	self:set_character_mask_by_id(outfit.mask.mask_id, outfit.mask.blueprint, unit, i)
	self:set_character_armor(outfit.armor, unit)
	self:set_character_deployable(outfit.deployable, unit, i)
	self:set_character_armor_skin(outfit.armor_skin or managers.blackmarket:equipped_armor_skin(), unit)
	self:_delete_character_weapon(unit, "all")

	local prio_item = self:_get_lobby_character_prio_item(rank, outfit)

	if prio_item == "rank" then
		self:set_character_card(i, rank, unit)
	else
		self:_select_lobby_character_pose(i, unit, outfit[prio_item])
		self:set_character_equipped_weapon(unit, outfit[prio_item].factory_id, outfit[prio_item].blueprint, "primary", outfit[prio_item].cosmetics)
	end

	local is_me = i == managers.network:session():local_peer():id()
	local mvec = Vector3()
	local math_up = math.UP
	local pos = Vector3()
	local rot = Rotation()

	mrotation.set_yaw_pitch_roll(rot, self._characters_rotation[i], 0, 0)
	mvector3.set(pos, self._characters_offset)
	mvector3.rotate_with(pos, rot)
	mvector3.set(mvec, pos)
	mvector3.negate(mvec)
	mvector3.set_z(mvec, 0)
	mvector3.set(mvec, mvec + Vector3(100, 150, 0))
	mrotation.set_look_at(rot, mvec, math_up)
	mvector3.set_x(pos, 50 + -80 * i)
	mvector3.set_z(pos, -135)
	unit:set_position(pos)
	unit:set_rotation(rot)
	self:set_lobby_character_visible(i, true)
end

function MenuSceneManager:_setup_lobby_characters()
	if self._lobby_characters then
		for _, unit in ipairs(self._lobby_characters) do
			self:_delete_character_mask(unit)
			World:delete_unit(unit)
		end
	end

	self._lobby_characters = {}
	self._characters_offset = Vector3(0, -200, -130)
	self._characters_rotation = {
		-69,
		-79,
		-89,
		-99
	}
	local masks = {}

	for i = 1, tweak_data.max_players, 1 do
		table.insert(masks, "dallas")
	end

	local mvec = Vector3()
	local math_up = math.UP
	local pos = Vector3()
	local rot = Rotation()

	for i = 1, tweak_data.max_players, 1 do

		mrotation.set_yaw_pitch_roll(rot, self._characters_rotation[i], 0, 0)
		mvector3.set(pos, self._characters_offset)
		mvector3.rotate_with(pos, rot)
		mvector3.set(mvec, pos)
		mvector3.negate(mvec)
		mvector3.set_z(mvec, 0)
		mvector3.set(mvec, mvec + Vector3(100, 150, 0))
		mrotation.set_look_at(rot, mvec, math_up)
		mvector3.set_x(pos, 50 + -80 * i)
		mvector3.set_z(pos, -135)

		local unit_name = tweak_data.blackmarket.characters.locked.menu_unit
		local unit = World:spawn_unit(Idstring(unit_name), pos, rot)

		self:_init_character(unit, i)
		self:set_character_mask(tweak_data.blackmarket.masks[masks[i]].unit, unit, nil, masks[i])
		table.insert(self._lobby_characters, unit)
		self:set_lobby_character_visible(i, false, true)
	end
end